@@ -1,5 +1,45 @@
 #!/usr/bin/env python
+r"""
+Quick start
+===========
 
+.. currentmodule:: biom
+
+BIOM has an example table and two methods for reading in `Table` objects that
+are immediately available at the package level.
+
+Functions
+---------
+
+.. autosummary::
+   :toctree: generated/
+
+   load_table
+
+Examples
+--------
+Load an example table:
+
+>>> from biom import example_table
+>>> print example_table # doctest: +NORMALIZE_WHITESPACE
+# Constructed from biom file
+#OTU ID S1  S2  S3
+O1  0.0 1.0 2.0
+O2  3.0 4.0 5.0
+
+Parse a table from an open file object:
+
+>>> from biom import parse_table
+>>> with open('path/to/table.biom') as f: # doctest: +SKIP
+...     table = parse_table(f)
+
+Parse a table from a path. BIOM will attempt to determine if the file is
+either in TSV, HDF5, JSON, gzip'd JSON or gzip'd TSV and parse accordingly:
+
+>>> from biom import load_table
+>>> table = load_table('path/to/table.biom') # doctest: +SKIP
+
+"""
 # ----------------------------------------------------------------------------
 # Copyright (c) 2011-2013, The BIOM Format Development Team.
 #
@@ -16,13 +56,13 @@ __credits__ = ["Daniel McDonald", "Jai Ram Rideout", "Greg Caporaso",
                "Rob Knight", "Joshua Shorenstein", "Emily TerAvest"]
 __license__ = "BSD"
 __url__ = "http://biom-format.org"
-__version__ = "2.0.0"
+__version__ = "2.1"
 __maintainer__ = "Daniel McDonald"
 __email__ = "daniel.mcdonald@colorado.edu"
-
+__format_version__ = (2, 1)
 
 from .table import Table
-from .parse import parse_biom_table as parse_table
+from .parse import parse_biom_table as parse_table, load_table
 
 example_table = Table([[0, 1, 2], [3, 4, 5]], ['O1', 'O2'],
                       ['S1', 'S2', 'S3'],
@@ -33,4 +73,4 @@ example_table = Table([[0, 1, 2], [3, 4, 5]], ['O1', 'O2'],
                        {'environment': 'A'}], input_is_dense=True)
 
 
-__all__ = ['Table', 'example_table', 'parse_table']
+__all__ = ['Table', 'example_table', 'parse_table', 'load_table']
